plot_kit_use: Plot of probability of naloxone kit use

View source: R/utils-plot.R

plot_kit_useR Documentation

Plot of probability of naloxone kit use

Description

plot can compare between two different model fits or a single model fit by region. If data are simulated then can also include in plot. For more details see the introduction vignette: vignette("Introduction", package = "bennu")

Usage

plot_kit_use(..., data = NULL, reported = FALSE, regions_to_plot = NULL)

Arguments

...

named list of rstan::stanfit objects

data

data used for model fitting. Can also include p_use column which can be used to plot true values if derived from simulated data.

reported

if TRUE then produces a plot of the reported kits which is equivalent to the predictive check.

regions_to_plot

Optional list to filter which regions are plotted

Value

ggplot2::ggplot object

See Also

Other plots: kit_summary_table()


bennu documentation built on Nov. 5, 2025, 6:45 p.m.