| plot_kit_use | R Documentation |
plot can compare between two different model fits or a single
model fit by region. If data are simulated then can also include in plot.
For more details see the introduction vignette:
vignette("Introduction", package = "bennu")
plot_kit_use(..., data = NULL, reported = FALSE, regions_to_plot = NULL)
... |
named list of rstan::stanfit objects |
data |
data used for model fitting. Can also include |
reported |
if |
regions_to_plot |
Optional list to filter which regions are plotted |
ggplot2::ggplot object
Other plots:
kit_summary_table()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.